
import { createRoot } from 'react-dom/client'
import App from './App.tsx'
import { AppErrorBoundary } from './components/error/AppErrorBoundary.tsx'
import { ProductionErrorBoundary } from './components/error/ProductionErrorBoundary.tsx'
import './index.css'
import { initSecureStorage } from './utils/secureStorage'
import { initSecurityMonitoring } from './utils/securityMonitoring'
import { initializeProductionConfig } from './utils/productionConfig'
import { performQuickSecurityCheck } from './utils/securityValidator'

// Initialize production configuration
initializeProductionConfig();

// Initialize security systems
initSecureStorage();
initSecurityMonitoring();

// Perform security check in development
if (import.meta.env.DEV) {
  performQuickSecurityCheck();
}


// Stealth Mode: Unregister any existing service workers
if ('serviceWorker' in navigator) {
  navigator.serviceWorker.getRegistrations().then((registrations) => {
    for (const registration of registrations) {
      registration.unregister();
    }
  });
}

// Privacy Mode: Remove unauthorized tracking only
const removeUnauthorizedTracking = () => {
  const images = document.querySelectorAll('img[src*="facebook.com/tr"]');
  images.forEach(img => img.remove());
};

document.addEventListener('DOMContentLoaded', removeUnauthorizedTracking);

// Render the app with enhanced error boundary
createRoot(document.getElementById("root")!).render(
  <ProductionErrorBoundary>
    <AppErrorBoundary>
      <App />
    </AppErrorBoundary>
  </ProductionErrorBoundary>
);
